aboutsummaryrefslogtreecommitdiff
path: root/src/net_processing.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/net_processing.h')
-rw-r--r--src/net_processing.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/src/net_processing.h b/src/net_processing.h
index a0cbe92289..b1e6e4eebb 100644
--- a/src/net_processing.h
+++ b/src/net_processing.h
@@ -18,7 +18,8 @@ class ChainstateManager;
static constexpr bool DEFAULT_TXRECONCILIATION_ENABLE{false};
/** Default for -maxorphantx, maximum number of orphan transactions kept in memory */
static const unsigned int DEFAULT_MAX_ORPHAN_TRANSACTIONS = 100;
-/** Default number of orphan+recently-replaced txn to keep around for block reconstruction */
+/** Default number of non-mempool transactions to keep around for block reconstruction. Includes
+ orphan, replaced, and rejected transactions. */
static const unsigned int DEFAULT_BLOCK_RECONSTRUCTION_EXTRA_TXN = 100;
static const bool DEFAULT_PEERBLOOMFILTERS = false;
static const bool DEFAULT_PEERBLOCKFILTERS = false;
@@ -46,11 +47,16 @@ class PeerManager : public CValidationInterface, public NetEventsInterface
{
public:
struct Options {
- /** Whether this node is running in -blocksonly mode */
+ //! Whether this node is running in -blocksonly mode
bool ignore_incoming_txs{DEFAULT_BLOCKSONLY};
+ //! Whether transaction reconciliation protocol is enabled
bool reconcile_txs{DEFAULT_TXRECONCILIATION_ENABLE};
+ //! Maximum number of orphan transactions kept in memory
uint32_t max_orphan_txs{DEFAULT_MAX_ORPHAN_TRANSACTIONS};
+ //! Number of non-mempool transactions to keep around for block reconstruction. Includes
+ //! orphan, replaced, and rejected transactions.
size_t max_extra_txs{DEFAULT_BLOCK_RECONSTRUCTION_EXTRA_TXN};
+ //! Whether all P2P messages are captured to disk
bool capture_messages{false};
};